@@ -1,20 +1,21 @@
-# @(#)$Ident: IPC.pm 2013-04-29 19:26 pjf ;
+# @(#)$Ident: IPC.pm 2013-06-25 23:02 pjf ;
 
 package Class::Usul::Response::IPC;
 
-use version; our $VERSION = qv( sprintf '0.21.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use namespace::sweep;
+use version; our $VERSION = qv( sprintf '0.22.%d', q$Rev: 2 $ =~ /\d+/gmx );
 
-use Class::Usul::Moose;
+use Class::Usul::Types qw( Int Object Str Undef );
+use Moo;
 
-has 'core'   => is => 'ro', isa => 'Int', default => 0;
-has 'out'    => is => 'ro', isa => 'Str', default => q();
-has 'pid'    => is => 'ro', isa => 'Maybe[Int]';
-has 'rv'     => is => 'ro', isa => 'Int', default => 0;
-has 'sig'    => is => 'ro', isa => 'Maybe[Int]';
-has 'stderr' => is => 'ro', isa => 'Str', default => q();
-has 'stdout' => is => 'ro', isa => 'Str', default => q();
-
-__PACKAGE__->meta->make_immutable;
+has 'core'    => is => 'ro', isa => Int, default => 0;
+has 'harness' => is => 'ro', isa => Object | Undef;
+has 'out'     => is => 'ro', isa => Str, default => q();
+has 'pid'     => is => 'ro', isa => Int | Undef;
+has 'rv'      => is => 'ro', isa => Int, default => 0;
+has 'sig'     => is => 'ro', isa => Int | Undef;
+has 'stderr'  => is => 'ro', isa => Str, default => q();
+has 'stdout'  => is => 'ro', isa => Str, default => q();
 
 1;
 
@@ -28,7 +29,7 @@ Class::Usul::Response::IPC - Response class for running external programs
 
 =head1 Version
 
-This documents version v0.21.$Rev: 1 $
+This documents version v0.22.$Rev: 2 $
 
 =head1 Synopsis
 
@@ -47,23 +48,35 @@ This class defined these attributes:
 
 =over 3
 
-=item core
+=item C<core>
 
 True if external commands core dumped
 
-=item out
+=item C<harness>
+
+The L<IPC::Run> harness object if one was used
+
+=item C<out>
 
 Processed output from the command
 
-=item sig
+=item C<pid>
+
+The id of the child process
+
+=item C<sig>
 
 Signal that caused the program to terminate
 
-=item stderr
+=item C<rv>
+
+The return value of from running the command
+
+=item C<stderr>
 
 The standard error output from the command
 
-=item stdout
+=item C<stdout>
 
 The standard output from the command
 
